# libpythonpro
Módulo para exemplificar construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto

Link para o curso [Python Pro](https://www.python.pro.br/)

[![Build Status](https://app.travis-ci.com/Rawston/libpythonpro.svg?branch=master)](https://app.travis-ci.com/Rawston/libpythonpro)
[![Updates](https://pyup.io/repos/github/Rawston/libpythonpro/shield.svg)](https://pyup.io/repos/github/Rawston/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/Rawston/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/Rawston/libpythonpro/)
Suportada versão 3 de Python

Para instalar:

```console
python3 -m venv .venv
.venv\Sctripts\activate
pip install -r reqirements-dev.txt
pip install pipenv
pipenv install --dev
```

Para conferir qualidade de código:

```console
pipenv run flake8
```

Tópicos a serem abordados:
 1. Git
 2. Virtualenv
 3. Pip
 4. Mock
 5. Pipenv
 